@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 from trytond.pool import Pool
 from .health import *
 from wizard import *
+from report import *
 
 def register():
     Pool.register(
@@ -32,6 +33,8 @@ def register():
         DomiciliaryUnit,
         Occupation,
         Ethnicity,
+        BirthCertificate,
+        DeathCertificate,
         PartyPatient,
         PartyAddress,
         DrugDoseUnits,
@@ -55,10 +58,16 @@ def register():
         FamilyMember,
         MedicamentCategory,
         Medicament,
+        ImmunizationSchedule,
+        ImmunizationScheduleLine,
+        ImmunizationScheduleDose,
         PathologyCategory,
         PathologyGroup,
         Pathology,
         DiseaseMembers,
+        BirthCertExtraInfo,
+        DeathCertExtraInfo,
+        DeathUnderlyingCondition,
         ProcedureCode,
         InsurancePlan,
         Insurance,
@@ -81,8 +90,16 @@ def register():
         SecondaryCondition,
         DiagnosticHypothesis,
         SignsAndSymptoms,
+        CheckImmunizationStatusInit,
         module='health', type_='model')
     Pool.register(
         OpenAppointmentReport,
         CreateAppointmentEvaluation,
+        CheckImmunizationStatus,
         module='health', type_='wizard')
+    Pool.register(
+        PatientDiseaseReport,
+        PatientMedicationReport,
+        PatientVaccinationReport,
+        ImmunizationStatusReport,
+        module='health', type_='report')
