@@ -30,7 +30,7 @@ info = dict(config.items('tryton'))
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 3, 2
+major_version, minor_version = 3, 4
 
 requires = []
 
@@ -57,6 +57,8 @@ setup(name='trytond_health',
     packages=[
         'trytond.modules.health',
         'trytond.modules.health.tests',
+        'trytond.modules.health.wizard',
+        'trytond.modules.health.report',
         ],
 
     package_data={
