@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -59,7 +59,7 @@ class PaperArchive(ModelSQL, ModelView):
         'get_patient_history', searcher='search_patient_code')
 
     requested_by = fields.Many2One(
-        'party.party', 'Resquested by',
+        'party.party', 'Requested by',
         domain=[('is_person', '=', True)], 
         help="Person who last requested the document")
 
