@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -62,7 +62,8 @@ class CreateLabTestOrder(Wizard):
             test_report_data = {}
 
             if lab_test_order.state == 'ordered':
-                raise Exception('The Lab test order is already created.')
+                self.raise_user_error(
+                    "The Lab test order is already created")
 
             test_report_data['test'] = lab_test_order.name.id
             test_report_data['patient'] = lab_test_order.patient_id.id
@@ -122,20 +123,13 @@ class RequestPatientLabTestStart(ModelView):
 
     @staticmethod
     def default_doctor():
-        cursor = Transaction().cursor
-        User = Pool().get('res.user')
-        user = User(Transaction().user)
-        login_user_id = int(user.id)
-        cursor.execute('SELECT id FROM party_party WHERE is_healthprof=True AND \
-            internal_user = %s LIMIT 1', (login_user_id,))
-        partner_id = cursor.fetchone()
-        if partner_id:
-            cursor = Transaction().cursor
-            cursor.execute('SELECT id FROM gnuhealth_healthprofessional WHERE \
-                name = %s LIMIT 1', (partner_id[0],))
-            doctor_id = cursor.fetchone()
-            return int(doctor_id[0])
-
+        pool = Pool()
+        HealthProf= pool.get('gnuhealth.healthprofessional')
+        hp = HealthProf.get_health_professional()
+        if not hp:
+            RequestPatientLabTestStart.raise_user_error(
+                "No health professional associated to this user !")
+        return hp
 
 class RequestPatientLabTest(Wizard):
     'Request Patient Lab Test'
