@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #    Copyright (C) 2013  Sebastian Marro <smarro@gnusolidario.org>
 #
@@ -31,11 +31,11 @@ from trytond.pool import Pool, PoolMeta
 
 __all__ = ['Medicament', 'Party', 'Lot', 'Move',
     'PatientAmbulatoryCare', 'PatientAmbulatoryCareMedicament',
-    'PatientAmbulatoryCareMedicalSupply', 'PatientAmbulatoryCareVaccine',
+    'PatientAmbulatoryCareMedicalSupply',
     'PatientRounding', 'PatientRoundingMedicament',
-    'PatientRoundingMedicalSupply', 'PatientRoundingVaccine',
-    'PatientPrescriptionOrder', 'CreatePrescriptionStockMoveInit',
-    'CreatePrescriptionStockMove']
+    'PatientRoundingMedicalSupply',
+    'PatientPrescriptionOrder', 'PatientVaccination']
+    
 __metaclass__ = PoolMeta
 
 _STATES = {
@@ -90,24 +90,7 @@ class Party:
 class Lot:
     __name__ = 'stock.lot'
     expiration_date = fields.Date('Expiration Date')
-    quantity = fields.Function(fields.Float('Quantity'), 'sum_lot_quantity')
-
-    def sum_lot_quantity(self, name):
-        Move = Pool().get('stock.move')
-
-        moves = Move.search([
-            ('lot', '=', self.id),
-            ('product', '=', self.product.id)
-        ])
-        quantity = 0
-        for move in moves:
-            if move.to_location.type == 'storage':
-                quantity += move.quantity
-            if move.from_location.type == 'storage':
-                quantity -= move.quantity
-        return quantity
-
-
+   
 class Move:
     __name__ = 'stock.move'
 
@@ -117,6 +100,7 @@ class Move:
             'gnuhealth.prescription.order',
             'gnuhealth.patient.ambulatory_care',
             'gnuhealth.patient.rounding',
+            'gnuhealth.vaccination',
             ]
 
 
@@ -128,8 +112,7 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
         domain=[('type', '=', 'storage')],
         states={
             'required': If(Or(Bool(Eval('medicaments')),
-                Bool(Eval('medical_supplies')),
-                Bool(Eval('vaccines'))), True, False),
+                Bool(Eval('medical_supplies'))), True, False),
             'readonly': Eval('state') == 'done',
         }, depends=['state', 'medicaments'])
     medicaments = fields.One2Many(
@@ -138,9 +121,7 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
     medical_supplies = fields.One2Many(
         'gnuhealth.patient.ambulatory_care.medical_supply', 'name',
         'Medical Supplies', states=_STATES, depends=_DEPENDS)
-    vaccines = fields.One2Many(
-        'gnuhealth.patient.ambulatory_care.vaccine', 'name', 'Vaccines',
-        states=_STATES, depends=_DEPENDS)
+
     moves = fields.One2Many('stock.move', 'origin', 'Stock Moves',
         readonly=True)
     state = fields.Selection([
@@ -178,12 +159,10 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
     def done(cls, ambulatory_cares):
         pool = Pool()
         Patient = pool.get('gnuhealth.patient')
-        Vaccination = pool.get('gnuhealth.vaccination')
 
         lines_to_ship = {}
         medicaments_to_ship = []
         supplies_to_ship = []
-        vaccines_to_ship = []
 
         for ambulatory in ambulatory_cares:
             patient = Patient(ambulatory.patient.id)
@@ -193,34 +172,8 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
             for medical_supply in ambulatory.medical_supplies:
                 supplies_to_ship.append(medical_supply)
 
-            vaccinations = []
-            for vaccine in ambulatory.vaccines:
-                lot_number = ''
-                expiration_date = None
-                if vaccine.lot:
-                    if vaccine.lot.number:
-                        lot_number = vaccine.lot.number
-                    if vaccine.lot.expiration_date:
-                        expiration_date = vaccine.lot.expiration_date
-                vaccination_data = {
-                    'name': patient.id,
-                    'vaccine': vaccine.vaccine.id,
-                    'vaccine_lot': lot_number,
-                    'institution': Transaction().context.get('company')
-                        or None,
-                    'date': datetime.now(),
-                    'dose': vaccine.dose,
-                    'next_dose_date': vaccine.next_dose_date,
-                    'vaccine_expiration_date': expiration_date,
-                    'admin_route': vaccine.admin_route,
-                    }
-                vaccinations.append(vaccination_data)
-                vaccines_to_ship.append(vaccine)
-            Vaccination.create(vaccinations)
-
         lines_to_ship['medicaments'] = medicaments_to_ship
         lines_to_ship['supplies'] = supplies_to_ship
-        lines_to_ship['vaccines'] = vaccines_to_ship
 
         cls.create_stock_moves(ambulatory_cares, lines_to_ship)
 
@@ -266,23 +219,6 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
                     move_info['lot'] = medical_supply.lot.id
                 moves.append(move_info)
 
-            for vaccine in lines['vaccines']:
-                move_info = {}
-                move_info['origin'] = str(ambulatory)
-                move_info['product'] = vaccine.vaccine.id
-                move_info['uom'] = vaccine.vaccine.default_uom.id
-                move_info['quantity'] = vaccine.quantity
-                move_info['from_location'] = ambulatory.care_location.id
-                move_info['to_location'] = \
-                    ambulatory.patient.name.customer_location.id
-                move_info['unit_price'] = vaccine.vaccine.list_price
-                if vaccine.lot:
-                    if  vaccine.lot.expiration_date \
-                    and vaccine.lot.expiration_date < Date.today():
-                        raise UserError('Expired vaccines')
-                    move_info['lot'] = vaccine.lot.id
-                moves.append(move_info)
-
         new_moves = Move.create(moves)
         Move.write(new_moves, {
             'state': 'done',
@@ -341,38 +277,6 @@ class PatientAmbulatoryCareMedicalSupply(ModelSQL, ModelView):
     def default_quantity():
         return 1
 
-
-class PatientAmbulatoryCareVaccine(ModelSQL, ModelView):
-    'Patient Ambulatory Care Vaccine'
-    __name__ = 'gnuhealth.patient.ambulatory_care.vaccine'
-
-    name = fields.Many2One('gnuhealth.patient.ambulatory_care',
-        'Ambulatory ID')
-    vaccine = fields.Many2One('product.product', 'Name', required=True,
-        domain=[('is_vaccine', '=', True)])
-    quantity = fields.Integer('Quantity')
-    dose = fields.Integer('Dose')
-    next_dose_date = fields.DateTime('Next Dose')
-    short_comment = fields.Char('Comment',
-        help='Short comment on the specific drug')
-    lot = fields.Many2One('stock.lot', 'Lot', depends=['vaccine'],
-        domain=[
-            ('product', '=', Eval('vaccine')),
-            ])
-    admin_route = fields.Selection([
-        (None, ''),
-        ('im', 'Intramuscular'),
-        ('sc', 'Subcutaneous'),
-        ('id', 'Intradermal'),
-        ('nas', 'Intranasal'),
-        ('po', 'Oral'),
-        ], 'Route', sort=False)
-
-    @staticmethod
-    def default_quantity():
-        return 1
-
-
 class PatientRounding(Workflow, ModelSQL, ModelView):
     'Patient Ambulatory Care'
     __name__ = 'gnuhealth.patient.rounding'
@@ -381,8 +285,7 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
         'Hospitalization Location', domain=[('type', '=', 'storage')],
         states={
             'required': If(Or(Bool(Eval('medicaments')),
-                Bool(Eval('medical_supplies')),
-                Bool(Eval('vaccines'))), True, False),
+                Bool(Eval('medical_supplies'))), True, False),
             'readonly': Eval('state') == 'done',
         }, depends=_DEPENDS)
     medicaments = fields.One2Many(
@@ -391,9 +294,6 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
     medical_supplies = fields.One2Many(
         'gnuhealth.patient.rounding.medical_supply', 'name', 'Medical Supplies',
         states=_STATES, depends=_DEPENDS)
-    vaccines = fields.One2Many(
-        'gnuhealth.patient.rounding.vaccine', 'name', 'Vaccines',
-        states=_STATES, depends=_DEPENDS,)
     moves = fields.One2Many('stock.move', 'origin', 'Stock Moves',
         readonly=True)
     state = fields.Selection([
@@ -430,12 +330,10 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
     def done(cls, roundings):
         pool = Pool()
         Patient = pool.get('gnuhealth.patient')
-        Vaccination = pool.get('gnuhealth.vaccination')
 
         lines_to_ship = {}
         medicaments_to_ship = []
         supplies_to_ship = []
-        vaccines_to_ship = []
 
         for rounding in roundings:
             patient = Patient(rounding.name.patient.id)
@@ -446,32 +344,9 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
             for medical_supply in rounding.medical_supplies:
                 supplies_to_ship.append(medical_supply)
 
-            for vaccine in rounding.vaccines:
-                lot_number = ''
-                expiration_date = None
-                if vaccine.lot:
-                    if vaccine.lot.number:
-                        lot_number = vaccine.lot.number
-                    if vaccine.lot.expiration_date:
-                        expiration_date = vaccine.lot.expiration_date
-                vaccination_data = {
-                    'name': patient.id,
-                    'vaccine': vaccine.vaccine.id,
-                    'vaccine_lot': lot_number,
-                    'institution': Transaction().context.get('company')
-                        or None,
-                    'date': datetime.now(),
-                    'dose': vaccine.dose,
-                    'next_dose_date': vaccine.next_dose_date,
-                    'vaccine_expiration_date': expiration_date,
-                    'admin_route': vaccine.admin_route,
-                    }
-                Vaccination.create([vaccination_data])
-                vaccines_to_ship.append(vaccine)
-
         lines_to_ship['medicaments'] = medicaments_to_ship
         lines_to_ship['supplies'] = supplies_to_ship
-        lines_to_ship['vaccines'] = vaccines_to_ship
+        
 
         cls.create_stock_moves(roundings, lines_to_ship)
 
@@ -516,23 +391,6 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
                         raise UserError('Expired supplies')
                     move_info['lot'] = medical_supply.lot.id
                 moves.append(move_info)
-            for vaccine in lines['vaccines']:
-                move_info = {}
-                move_info['origin'] = str(rounding)
-                move_info['product'] = vaccine.vaccine.id
-                move_info['uom'] = vaccine.vaccine.default_uom.id
-                move_info['quantity'] = vaccine.quantity
-                move_info['from_location'] = \
-                    rounding.hospitalization_location.id
-                move_info['to_location'] = \
-                rounding.name.patient.name.customer_location.id
-                move_info['unit_price'] = vaccine.vaccine.list_price
-                if vaccine.lot:
-                    if  vaccine.lot.expiration_date \
-                    and vaccine.lot.expiration_date < Date.today():
-                        raise UserError('Expired vaccines')
-                    move_info['lot'] = vaccine.lot.id
-                moves.append(move_info)
         new_moves = Move.create(moves)
         Move.write(new_moves, {
             'state': 'done',
@@ -590,36 +448,6 @@ class PatientRoundingMedicalSupply(ModelSQL, ModelView):
         return 1
 
 
-class PatientRoundingVaccine(ModelSQL, ModelView):
-    'Patient Ambulatory Care Vaccine'
-    __name__ = 'gnuhealth.patient.rounding.vaccine'
-
-    name = fields.Many2One('gnuhealth.patient.rounding', 'Rounding ID')
-    vaccine = fields.Many2One('product.product', 'Name', required=True,
-        domain=[('is_vaccine', '=', True)])
-    quantity = fields.Integer('Quantity')
-    dose = fields.Integer('Dose')
-    next_dose_date = fields.DateTime('Next Dose')
-    short_comment = fields.Char('Comment',
-        help='Short comment on the specific drug')
-    lot = fields.Many2One('stock.lot', 'Lot', depends=['vaccine'],
-        domain=[
-            ('product', '=', Eval('vaccine')),
-            ])
-    admin_route = fields.Selection([
-        (None, ''),
-        ('im', 'Intramuscular'),
-        ('sc', 'Subcutaneous'),
-        ('id', 'Intradermal'),
-        ('nas', 'Intranasal'),
-        ('po', 'Oral'),
-        ], 'Route', sort=False)
-
-    @staticmethod
-    def default_quantity():
-        return 1
-
-
 class PatientPrescriptionOrder:
     __name__ = 'gnuhealth.prescription.order'
     moves = fields.One2Many('stock.move', 'origin', 'Moves', readonly=True)
@@ -634,59 +462,48 @@ class PatientPrescriptionOrder:
             prescriptions, default=default)
 
 
-class CreatePrescriptionStockMoveInit(ModelView):
-    'Create Prescription Stock Move Init'
-    __name__ = 'gnuhealth.prescription.stock.move.init'
+class PatientVaccination:
+    __name__ = 'gnuhealth.vaccination'
+    moves = fields.One2Many('stock.move', 'origin', 'Moves', readonly=True)
+    location = fields.Many2One('stock.location',
+        'Stock Location', domain=[('type', '=', 'storage')])
+
+    product = fields.Many2One('product.product', 'Product')
+
+    lot = fields.Many2One('stock.lot', 'Lot', depends=['product'],
+        domain=[('product', '=', Eval('product'))],
+        help="This field includes the lot number and expiration date")
 
 
-class CreatePrescriptionStockMove(Wizard):
-    'Create Prescription Stock Move'
-    __name__ = 'gnuhealth.prescription.stock.move.create'
-
-    start = StateView('gnuhealth.prescription.stock.move.init',
-            'health_stock.view_create_prescription_stock_move', [
-            Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Create Stock Move', 'create_stock_move',
-                'tryton-ok', True),
-            ])
-    create_stock_move = StateTransition()
-
-    def transition_create_stock_move(self):
-        pool = Pool()
-        StockMove = pool.get('stock.move')
-        Prescription = pool.get('gnuhealth.prescription.order')
-
-        prescriptions = Prescription.browse(Transaction().context.get(
-            'active_ids'))
-        for prescription in prescriptions:
-
-            if prescription.moves:
-                raise Exception('Stock moves already exists!.')
-
-            if not prescription.pharmacy:
-                raise Exception('You need to enter a pharmacy.')
-
-            lines = []
-            for line in prescription.prescription_line:
-                line_data = {}
-                line_data['origin'] = str(prescription)
-                line_data['from_location'] = \
-                    prescription.pharmacy.warehouse.storage_location.id
-                line_data['to_location'] = \
-                    prescription.patient.name.customer_location.id
-                line_data['product'] = \
-                    line.medicament.name.id
-                line_data['unit_price'] = \
-                    line.medicament.name.list_price
-                line_data['quantity'] = line.quantity
-                line_data['uom'] = \
-                    line.medicament.name.default_uom.id
-                line_data['state'] = 'draft'
-                lines.append(line_data)
-            moves = StockMove.create(lines)
-            StockMove.assign(moves)
-            StockMove.do(moves)
-
-        return 'end'
+    @fields.depends('lot')
+    def on_change_lot(self):
+        # Check expiration date on the vaccine lot
+        if self.lot:
+            if self.lot.expiration_date < datetime.date(self.date):
+                self.raise_user_error('expired_vaccine')
+        return {}
+    @classmethod
+    def copy(cls, vaccinations, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default['moves'] = None
+        return super(PatientVaccination, cls).copy(
+            vaccinations, default=default)
 
+    @classmethod
+    def __setup__(cls):
+        super(PatientVaccination, cls).__setup__()
+        cls._error_messages.update({
+            'expired_vaccine': 'EXPIRED VACCINE. PLEASE INFORM  THE LOCAL '
+                'HEALTH AUTHORITIES AND DO NOT USE IT !!!',
+        })
 
+    @fields.depends('vaccine', 'product')
+    def on_change_vaccine(self):
+        res = {}
+        if self.vaccine:
+            res = {'product': self.vaccine.name.id}
+        else:
+            res = {'product': None}
+        return res
